@@ -7,8 +7,8 @@
 #include "drivermanager.h"
 #include "utils.h"
 #include "modcore.h"
-#include "debinstaller.h"
-#include "driverinstaller.h"
+#include "aptinstaller.h"
+#include "driverinstallerapt.h"
 //#include "DeviceInfoManager.h"
 #include "httpdriverinterface.h"
 #include "DDLog.h"
@@ -32,7 +32,11 @@
 #include <QJsonArray>
 #include <QThread>
 #include <QDBusInterface>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)  
 #include <QNetworkConfigurationManager>
+#else
+#include <QNetworkInformation>
+#endif
 #include <QDir>
 #include <QFileInfoList>
 #include <QLoggingCategory>
@@ -41,7 +45,7 @@
 #include <string>
 #include <vector>
 
-#define DB_PATH "/usr/share/deepin-devicemanager"  //driver deb backup path
+#define DB_PATH "/var/lib/deepin-devicemanager"  //driver deb backup path
 #define SD_KEY_excat    "excat"
 #define SD_KEY_ver      "version"
 #define SD_KEY_code     "client_code"
@@ -71,12 +75,12 @@ DriverManager::DriverManager(QObject *parent)
     , mp_modcore(new ModCore(this))
 {
     mp_deboperatethread = new QThread(this);
-    mp_debinstaller = new DebInstaller;
+    mp_debinstaller = new AptInstaller;
     mp_debinstaller->moveToThread(mp_deboperatethread);
     mp_deboperatethread->start();
 
     mp_driverOperateThread = new QThread(this);
-    mp_driverInstaller = new DriverInstaller;
+    mp_driverInstaller = new DriverInstallerApt;
     mp_driverInstaller->moveToThread(mp_driverOperateThread);
     mp_driverOperateThread->start();
 
@@ -94,7 +98,7 @@ DriverManager::~DriverManager()
 
 void DriverManager::initConnections()
 {
-    connect(mp_debinstaller, &DebInstaller::installFinished, [&](bool bsuccess) {
+    connect(mp_debinstaller, &AptInstaller::installFinished, [&](bool bsuccess) {
         if (bsuccess) {
             sigProgressDetail(90, tr("Install success"));
         } else {
@@ -102,19 +106,19 @@ void DriverManager::initConnections()
         }
         sigFinished(bsuccess, errmsg);
     });
-    connect(mp_debinstaller, &DebInstaller::progressChanged, [&](int iprocess) {
+    connect(mp_debinstaller, &AptInstaller::progressChanged, [&](int iprocess) {
         m_installprocess = 20 + static_cast<int>(iprocess * 0.8);
         sigProgressDetail(m_installprocess, errmsg);
     });
-    connect(mp_debinstaller, &DebInstaller::errorOccurred, [&](QString errmsg) {
+    connect(mp_debinstaller, &AptInstaller::errorOccurred, [&](QString errmsg) {
         qCInfo(appLog) << "signal_installFailedReason:" << errmsg;
         sigFinished(false, errmsg);
         this->errmsg = errmsg;
     });
-    connect(this, &DriverManager::sigDebInstall, mp_debinstaller, &DebInstaller::installPackage);
-    connect(this, &DriverManager::sigDebUnstall, mp_debinstaller, &DebInstaller::uninstallPackage);
+    connect(this, &DriverManager::sigDebInstall, mp_debinstaller, &AptInstaller::installPackage);
+    connect(this, &DriverManager::sigDebUnstall, mp_debinstaller, &AptInstaller::uninstallPackage);
 
-    connect(mp_driverInstaller, &DriverInstaller::installProgressFinished, [&](bool bsuccess) {
+    connect(mp_driverInstaller, &DriverInstallerApt::installProgressFinished, [&](bool bsuccess) {
         if (bsuccess) {
             sigInstallProgressFinished(bsuccess, EC_NULL);
             qCInfo(appLog) << "Driver installed successfully";
@@ -123,7 +127,7 @@ void DriverManager::initConnections()
         }
     });
 
-    connect(mp_driverInstaller, &DriverInstaller::errorOccurred, [this](int err) {
+    connect(mp_driverInstaller, &DriverInstallerApt::errorOccurred, [this](int err) {
         if (EC_NETWORK != err) {
             qCInfo(appLog) << "Driver installation failed , reason : " << err;
             sigInstallProgressFinished(false, err);
@@ -157,7 +161,7 @@ void DriverManager::initConnections()
         sigInstallProgressFinished(false, EC_NETWORK);
     });
 
-    connect(mp_driverInstaller, &DriverInstaller::installProgressChanged, [&](int progress) {
+    connect(mp_driverInstaller, &DriverInstallerApt::installProgressChanged, [&](int progress) {
         sigInstallProgressChanged(progress);
         qCInfo(appLog) << "Installing driver ,  installation progress : " << progress;
     });
@@ -198,6 +202,13 @@ bool DriverManager::unInstallDriver(const QString &modulename)
     return  bsuccess;
 }
 
+static void depmod_a()
+{
+    QProcess process;
+    process.start("depmod -a");
+    process.waitForFinished(-1);
+}
+
 bool DriverManager::installDriver(const QString &filepath)
 {
     /*1.检查模块是否已存在 存在报错返回，不报错返回
@@ -230,7 +241,7 @@ bool DriverManager::installDriver(const QString &filepath)
     //模块已被加载
     /*
      * 下面代码由 liujun 于 2021年11月9号 注释
-     * 为修复bug https://pms.uniontech.com/zentao/bug-view-101808.html
+     * 为修复bug 101808
     */
 //    if (mp_modcore->modIsLoaded(filepath)) {
 //        sigProgressDetail(10, QString("could not insert module %1 :file exist").arg(filepath));
@@ -285,9 +296,7 @@ bool DriverManager::installDriver(const QString &filepath)
                     QFile::remove(installpath);
 
                     //删除后执行depmod更新
-                    QProcess process;
-                    process.start("depmod -a");
-                    process.waitForFinished(-1);
+                    depmod_a();
 
                     sigFinished(false, errmsg);
                     return  false;
@@ -364,6 +373,11 @@ bool DriverManager::isDriverPackage(const QString &filepath)
  */
 bool DriverManager::isSigned(const QString &filepath)
 {
+    // If hierarchical verification is enabled, we assume that all packages are signed.
+    if (Utils::HierarchicalVerifyAvailable == Utils::hierarchicalEnabled()) {
+        return true;
+    }
+
     //如果是开发者模式，直接返回true
     QDBusInterface *dbusInterFace = new QDBusInterface("com.deepin.sync.Helper", "/com/deepin/sync/Helper",
                                                        "com.deepin.sync.Helper", QDBusConnection::systemBus());
@@ -387,9 +401,8 @@ bool DriverManager::isSigned(const QString &filepath)
         strSignCheckString = "Verified successfully";
     }
 
-    QString outInfo;
-    bool ret = Utils::runCmdSafeWithArgs(outInfo, program, arguments, -1);
-    return (ret && outInfo.contains(strSignCheckString));
+    QString outInfo = Utils::executeServerCmd(program, arguments, QString(), -1, true);
+    return outInfo.contains(strSignCheckString);
 }
 bool DriverManager::isArchMatched(const QString &path)
 {
@@ -405,7 +418,7 @@ bool DriverManager::isDebValid(const QString &filePath)
     QMimeDatabase typedb;
     QMimeType filetype = typedb.mimeTypeForFile(filePath);
     if (filetype.filterString().contains("deb"))
-        return  mp_debinstaller->isDebValid(filePath);
+        return mp_debinstaller->isDebValid(filePath);
     return true;
 }
 
@@ -438,11 +451,28 @@ bool DriverManager::unInstallModule(const QString &moduleName, QString &msg)
 
 bool DriverManager::isNetworkOnline()
 {
-    /*
-       -c 2（代表ping次数，ping 2次后结束ping操作） -w 2（代表超时时间，2秒后结束ping操作）
-    */
-// system("ping www.google.com -c 2 -w 2 >netlog.bat");
-    system("ping www.baidu.com -c 2 -w 2 >netlog.bat");
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QNetworkConfigurationManager mgr;
+    if (!mgr.isOnline()) {
+        return false;
+    }
+#else
+    if (!QNetworkInformation::instance() || 
+        QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Disconnected) {
+        return false;
+    }
+#endif
+
+    // 继续执行 ping 测试以确保实际网络连接
+    QProcess process;
+    process.setStandardOutputFile("netlog.bat", QIODevice::WriteOnly);
+    process.start("ping", QStringList() << "www.baidu.com" << "-c" << "2" << "-w" << "2");
+    process.waitForFinished(-1);
+    bool bRet = (process.exitStatus() == QProcess::NormalExit && process.exitCode() == 0);
+    if (!bRet) {
+        return false;
+    }
+
     sleep(2);
 
     //把文件一行一行读取放入vector
@@ -710,20 +740,15 @@ bool DriverManager::delDeb(const QString &debname)
     }
     return (!destdir.exists());
 }
-
-bool DriverManager::aptUpdate()
+static void cmdAptUpdate()
 {
     QProcess process;
-    /* connect(&process, &QProcess::readyReadStandardOutput, this, [&](){
-        QByteArray outArry = process.readAllStandardOutput();
-        QList<QString> lines = QString(outArry).split('\n', QString::SkipEmptyParts);
-        for (const QString &line : qAsConst(lines)) {
-            // qCDebug() << line;
-            // error handling...
-        }
-    }); */
     process.start("apt update");
     process.waitForFinished(-1);
+}
+bool DriverManager::aptUpdate()
+{
+    cmdAptUpdate();
     return true;
 }
 
