@@ -4,6 +4,7 @@
 
 // 项目自身文件
 #include "DeviceInfo.h"
+#include "commonfunction.h"
 #include "commondefine.h"
 #include"DeviceManager.h"
 #include "DDLog.h"
@@ -13,7 +14,7 @@
 #include <QLoggingCategory>
 #include <QProcess>
 #include <QMap>
-
+#include <QRegularExpression>
 using namespace DDLog;
 
 DWIDGET_USE_NAMESPACE
@@ -492,14 +493,9 @@ bool DeviceBaseInfo::driverIsKernelIn(const QString &driver)
         return false;
     }
 
-    QString info = "";
-    QProcess process;
-
     // 判断lsmod是否能查询
-    process.start("sh", QStringList() << "-c" << QString("modinfo %1 | grep 'filename:'").arg(driver));
-    process.waitForFinished(-1);
-    info = process.readAllStandardOutput();
-    return info.isEmpty();
+    QString outInfo = Common::executeClientCmd("modinfo", QStringList() << driver, QString(), -1);
+    return !outInfo.contains("filename:");
 }
 
 void DeviceBaseInfo::setCanEnale(bool can)
@@ -575,25 +571,27 @@ const QString DeviceBaseInfo::getVendorOrModelId(const QString &sysPath, bool fl
     QString vendor = vendorFile.readAll();
     vendorFile.close();
 
-    return vendor;
+    return vendor.trimmed();
 }
 
 const QString DeviceBaseInfo::getDriverVersion()
 {
-    QProcess process;
-    process.start("bash", QStringList() << "-c" << "modinfo " + driver()  + "| grep version");
-    process.waitForFinished(-1);
+    QString outInfo = Common::executeClientCmd("modinfo", QStringList() << driver(), QString(), -1);
+    if(outInfo.isEmpty())
+        return  QString("");
 
-    QString output = process.readAllStandardOutput();
-
-    foreach (QString out, output.split("\n")) {
+    foreach (QString out, outInfo.split("\n")) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         QStringList item = out.split(":", QString::SkipEmptyParts);
+#else
+        QStringList item = out.split(":", Qt::SkipEmptyParts);
+#endif
         if (!item.isEmpty() && "version" == item[0].trimmed()) {
             return item[1].trimmed();
         }
     }
 
-    return "";
+    return QString("");
 }
 
 const QString DeviceBaseInfo::getOverviewInfo()
@@ -761,6 +759,21 @@ void DeviceBaseInfo::setHwinfoLshwKey(const QMap<QString, QString> &mapInfo)
                        << "i" << "j" << "k" << "l" << "m" << "n"
                        << "o" << "p" << "q" << "r" << "s" << "t"
                        << "u" << "v" << "w" << "x" << "y" << "z";
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QRegularExpression reg("([0-9a-zA-Z]+)-([0-9a-zA-Z]+)\\.([0-9a-zA-Z]+)");
+    QRegularExpressionMatch match = reg.match(words[0]);
+    if (match.hasMatch()) {
+        int first = match.captured(1).toInt();
+        int second = match.captured(2).toInt();
+        int third = match.captured(3).toInt();
+        m_HwinfoToLshw = QString("usb@%1:%2.%3").arg(nums.at(first)).arg(nums.at(second)).arg(nums.at(third));
+    } else {
+        int first = chs[0].toInt();
+        int second = chs[1].toInt();
+        m_HwinfoToLshw = QString("usb@%1:%2").arg(nums.at(first)).arg(nums.at(second));
+    }
+#else
     QRegExp reg("([0-9a-zA-Z]+)-([0-9a-zA-Z]+)\\.([0-9a-zA-Z]+)");
     if (reg.exactMatch(words[0])) {
         int first = reg.cap(1).toInt();
@@ -772,6 +785,7 @@ void DeviceBaseInfo::setHwinfoLshwKey(const QMap<QString, QString> &mapInfo)
         int second = chs[1].toInt();
         m_HwinfoToLshw = QString("usb@%1:%2").arg(nums.at(first)).arg(nums.at(second));
     }
+#endif
 }
 
 bool DeviceBaseInfo::matchToLshw(const QMap<QString, QString> &mapInfo)
