@@ -30,6 +30,8 @@
 #include "DeviceCdrom.h"
 #include "DeviceInput.h"
 #include "MacroDefinition.h"
+#include <QRegularExpression>   
+#include <algorithm> // for std::sort
 
 using namespace DDLog;
 
@@ -735,6 +737,7 @@ void DeviceManager::setStorageInfoFromSmartctl(const QString &name, const QMap<Q
 
 void DeviceManager::mergeDisk()
 {
+    QList<int> m_ListStorageIndex;
     QMap<QString, QList<int> > allSerialIDs;
     for (int i = 0; i < m_ListDeviceStorage.size(); ++i) {
         DeviceStorage *device = dynamic_cast<DeviceStorage *>(m_ListDeviceStorage[i]);
@@ -749,10 +752,17 @@ void DeviceManager::mergeDisk()
         for (int i = serialIDs.size() - 1; i > 0; --i) {
             DeviceStorage *curDevice = dynamic_cast<DeviceStorage *>(m_ListDeviceStorage[serialIDs[i] ]);
             fDevice->appendDisk(curDevice);
-            m_ListDeviceStorage.removeAt(serialIDs[i]);
-            delete curDevice;
+            m_ListStorageIndex.append(serialIDs[i]);
         }
     }
+
+    std::sort(m_ListStorageIndex.begin(), m_ListStorageIndex.end(), std::greater<int>());
+    for(auto index : m_ListStorageIndex) {
+        DeviceStorage *curDevice = dynamic_cast<DeviceStorage *>(m_ListDeviceStorage[index]);
+        m_ListDeviceStorage.removeAt(index);
+        delete curDevice;
+    }
+
     for (int i = 0; i < m_ListDeviceStorage.size(); ++i) {
         DeviceStorage *device = dynamic_cast<DeviceStorage *>(m_ListDeviceStorage[i]);
         device->unitConvertByDecimal();
@@ -1013,7 +1023,11 @@ DeviceBaseInfo *DeviceManager::getAudioDevice(const QString &path)
         DeviceAudio *audio = dynamic_cast<DeviceAudio *>(*it);
         QString tpath = audio->uniqueID();
         // 判断该设备是否已经存在，1.1:1.1 -> 1.1:1.0
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         if (audio && path == tpath.replace(QRegExp("[1-9]$"), "0")) {
+#else
+        if (audio && path == tpath.replace(QRegularExpression("[1-9]$"), "0")) {
+#endif
             return *it;
         }
         QString syspath = audio->sysPath();   //remove dumplicate syspath
@@ -1029,7 +1043,6 @@ DeviceBaseInfo *DeviceManager::getAudioDevice(const QString &path)
         if (audio && path == vidpid) {
             return *it;
         }
-
     }
     return nullptr;
 }
